"""
Luna-video-agent client module
"""

from numbers import Real
from typing import Awaitable, Optional, Union

import aiohttp

from luna3.common.base_api import BaseHTTPAPI
from luna3.common.luna_response import LunaResponse
from luna3.common.requests import RequestPayload
from luna3.public.sdk import VideoSDKInput


class VideoAgentApi(BaseHTTPAPI):
    """
    Class for request to luna-video-agent
    """

    def __init__(
        self,
        origin: Optional[str] = "http://127.0.0.1:5240",
        api: Optional[int] = 1,
        asyncRequest: Optional[bool] = False,
        lunaRequestId: Optional[str] = None,
        totalTimeout: Real = 60,
        connectTimeout: Optional[Real] = None,
        sockReadTimeout: Optional[Real] = None,
        sockConnectTimeout: Optional[Real] = None,
        *,
        session: aiohttp.ClientSession = None,
        echo: bool = False,
        **kwargs,
    ):
        super().__init__(
            origin=origin,
            api=api,
            asyncRequest=asyncRequest,
            lunaRequestId=lunaRequestId,
            totalTimeout=totalTimeout,
            connectTimeout=connectTimeout,
            sockReadTimeout=sockReadTimeout,
            sockConnectTimeout=sockConnectTimeout,
            session=session,
            echo=echo,
            **kwargs,
        )

    def videosdk(self, videoSDKInput: VideoSDKInput, **kwargs) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Process video

        Args:
            videoSDKInput: video properties including url and analytics params

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` json with samples, exif, filename for succeeded images and
            errors for failed images will be returned.

        """
        payload = RequestPayload.buildJson(videoSDKInput.asDict())
        return self.makeRequest(f"{self.baseUri}/videosdk", "POST", body=payload, **kwargs)
